# beautifulplots

Python plotting library for beautiful, easy, and sophisticated matplotlib based plots. Compatible with Matplotlib graphs, such as Pandas and Seaborn.

## Motivation
Data scientists use data visualization for analysis, investigation, insight, and story telling. In this endeavor, Matplotlib based plotting libraries are reputedly the most powerful and customizable. However, creating graphs for analysis, though necessary, often diverges from the primary goal. Furthermore, Graphs resulting from data science analysis inevitably populate reports, presentations, and even interactive web graphics. After some experience, use case after use case requires similar supporting code. 

## Goal
The goal of the beautifulplots plotting library is to package graphing functions for the easy generation of beautiful graphs without the burden of distracting code.

## Installation

```bash
$ pip install beautifulplots
```

## Usage and Examples

- See usage examples in examples.ipynb (Jupyter notebook) and readthedocs [beatifulplots readthedocs](https://beautifulplots.readthedocs.io/en/latest/index.html).


## Feature Requests and Issues

Feature requests and issues: please provide feedback and suggestions for improvements or issues via github issues [new issue](https://github.com/Aljgutier/beautifulplots/issues).


## License

`beautifulplots` was created by Alberto Gutierrez. It is licensed under the terms of the MIT license.

## Credits

`beautifulplots` package setup with  [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
